@@ -5,12 +5,12 @@ from typing import Union
 
 def get_image_type(p: Union[str, Path]) -> str:
     """Returns the type of image, i.e. jpeg or png."""
-    if not isinstance(p, Path):
-        p = Path(p)
-    return ''.join(p.suffixes).replace('.', '', 1)
+    if isinstance(p, Path):
+        return p.suffix
+    return p.split('.')[-1]
 
 
-def build_default_rupload_params(obj, quality: int, is_sidecar: bool) -> dict:
+def build_default_rupload_params(obj, quality: int) -> dict:
     """Builds default parameters used to upload media."""
     return {
         'upload_id': obj.upload_id,
@@ -25,6 +25,5 @@ def build_default_rupload_params(obj, quality: int, is_sidecar: bool) -> dict:
             'lib_name': 'moz',
             'lib_version': '3.1.m',
             'quality': str(quality)
-        }),
-        "is_sidecar": str(int(is_sidecar))
+        })
     }
\ No newline at end of file
