@@ -1,15 +1,13 @@
 import json
 import hmac
-import random
-from time import time
 
 from requests import Session, Response
-from typing import Callable, Union, List, Tuple, Dict
+from typing import Callable, Union
 from instauto.api.actions.stubs import _request
 
+
 from ..structs import Method, State, DeviceProfile, IGProfile, PostLocation
-from .structs.post import PostFeed, PostStory, Comment, UpdateCaption, Save, Like, Unlike, Device, RetrieveByUser, \
-    Location, RetrieveByTag, RetrieveLikers, RetrieveCommenters, UserTag, UserTags
+from .structs.post import PostFeed, PostStory, Comment, UpdateCaption, Save, Like, Unlike, Device, RetrieveByUser, Location, RetrieveByTag
 
 from ..exceptions import BadResponse
 
@@ -80,18 +78,13 @@ class PostMixin:
 
         return str(as_json['venues'][0]['external_id'])
 
-    def _upload_image(self, obj: Union[PostStory, PostFeed], quality: int, is_sidecar: bool = False) -> Tuple[Response, dict]:
-        if obj.device is None:
-            d = Device(self.device_profile.manufacturer, self.device_profile.model,
-                       int(self.device_profile.android_sdk_version), self.device_profile.android_release)
-            obj.device = d
-
+    def _upload_image(self, obj: Union[PostStory, PostFeed], quality: int) -> dict:
         as_dict = obj.fill(self).to_dict()
         headers = {
             'x-fb-photo-waterfall-id': str(as_dict.pop('x_fb_waterfall_id')),
             'x-entity-length': str(as_dict.pop('entity_length')),
             'x-entity-name': as_dict.pop('entity_name'),
-            'x-instagram-rupload-params': json.dumps(build_default_rupload_params(obj, quality, is_sidecar)),
+            'x-instagram-rupload-params': json.dumps(build_default_rupload_params(obj, quality)),
             'x-entity-type': as_dict.pop('entity_type'),
             'offset': '0',
             'scene_capture_type': 'standard',
@@ -104,16 +97,15 @@ class PostMixin:
                 obj.location.facebook_places_id = self._request_fb_places_id(obj.location)
             as_dict['location'] = json.dumps(obj.location.__dict__)
 
-        if hasattr(obj, 'usertags') and obj.usertags is not None:
-            data = obj.usertags.to_dict()
-            for i, usertag in enumerate(data['in']):
-                data['in'][i] = usertag.to_dict()
-            as_dict['usertags'] = json.dumps(data)
+        if obj.device is None:
+            d = Device(self.device_profile.manufacturer, self.device_profile.model,
+                       int(self.device_profile.android_sdk_version), self.device_profile.android_release)
+            obj.device = d
 
         with open(path, 'rb') as f:
-            resp = self._request(f'https://i.instagram.com/rupload_igphoto/{headers["x-entity-name"]}', Method.POST,
+            self._request(f'https://i.instagram.com/rupload_igphoto/{headers["x-entity-name"]}', Method.POST,
                           headers=headers, data=f.read())
-        return resp, as_dict
+        return as_dict
 
     def post_post(self, obj: Union[PostStory, PostFeed], quality: int = None) -> Response:
         """Uploads a new picture/video to your Instagram account.
@@ -130,7 +122,7 @@ class PostMixin:
         """
         if quality is None:
             quality = 70
-        as_dict = self._upload_image(obj, quality)[1]
+        as_dict = self._upload_image(obj, quality)
         headers = {
             'retry_context': json.dumps({"num_reupload": 0, "num_step_auto_retry": 0, "num_step_manual_retry": 0})
         }
@@ -167,6 +159,7 @@ class PostMixin:
         obj.page += 1
         return obj, resp_as_json['items']
 
+
     def post_retrieve_by_tag(self, obj: RetrieveByTag) -> (RetrieveByTag, Union[dict, bool]):
         as_dict = obj.to_dict()
 
@@ -182,63 +175,19 @@ class PostMixin:
         obj.page += 1
         return obj, resp_as_json['items']
 
-    def post_get_likers(self, obj: RetrieveLikers) -> [any]:
+
+    def post_get_likers(self, media_id: str) -> [any]:
         """Retrieve all likers of specific media_id"""
-        endpoint = 'media/{media_id}/likers'.format(media_id=obj.media_id)
+        endpoint = 'media/{media_id}/likers'.format(**{'media_id': media_id})
         resp = self._request(endpoint=endpoint, method=Method.GET)
-        users_as_json = resp.json()['users']
+        users_as_json = resp.json().get('users')
+
         return users_as_json
 
-    def post_get_commenters(self, obj: RetrieveCommenters) -> [any]:
-        endpoint = 'media/{media_id}/comments'.format(media_id=obj.media_id)
+      
+    def post_get_commenters(self, media_id: str) -> [any]:
+        endpoint = 'media/{media_id}/comments'.format(**{'media_id': media_id})
         resp = self._request(endpoint=endpoint, method=Method.GET)
-        users_as_json = [c['user'] for c in resp.json()['comments']]
+        users_as_json = resp.json().get('users')
+
         return users_as_json
-
-    def post_carousel(self, posts: List[PostFeed], caption: str, quality: int) -> Dict[str, Response]:
-        upload_id = str(time()).split('.')[0]
-
-        data = {
-            "timezone_offset": posts[0].timezone_offset,
-            "_csrftoken": self._session.cookies['csrftoken'],
-            "source_type": str(PostLocation.Feed.value),
-            "_uid": self.state.user_id,
-            "device_id": self.state.android_id,
-            "_uuid": self.state.uuid,
-            "creation_logger_session_id": self._gen_uuid(),
-            "caption": caption,
-            "device": posts[0].to_dict()['device'],
-            "client_sidecar_id": upload_id,
-            "children_metadata": [],
-        }
-
-        for post in posts:
-            data['children_metadata'].append(
-                {
-                    "scene_capture_type": post.scene_capture_type,
-                    "upload_id": post.upload_id,
-                    "caption": post.caption,
-                    "timezone_offset": post.timezone_offset,
-                    "source_type": str(post.source_type),
-                    "scene_type": None,
-                    "edits": json.dumps(post.to_dict()['edits']),
-                    "extra": json.dumps(post.to_dict()['extra']),
-                    "device": json.dumps(post.to_dict()['device'])
-                }
-            )
-            if hasattr(post, 'usertags'):
-                usertags = post.usertags.to_dict()
-                for i, usertag in enumerate(data['in']):
-                    usertags['in'][i] = usertag.to_dict()
-                data['children_metadata'][-1]['usertags'] = json.dumps(usertags)
-
-        headers = {
-            'retry_context': json.dumps({"num_reupload": 0, "num_step_auto_retry": 0, "num_step_manual_retry": 0})
-        }
-
-        responses: Dict[str, Response] = dict()
-        for i, post in enumerate(posts):
-            responses[f'post{i}'] = self._upload_image(post, quality, True)
-
-        responses['configure_sidecar'] = self._request('media/configure_sidecar/', Method.POST, data=data, headers=headers, signed=True)
-        return responses
