@@ -1,5 +1,3 @@
-import os
-
 import requests
 import time
 import json
@@ -10,7 +8,7 @@ from typing import Dict, Callable, Union
 
 from instauto.api.structs import DeviceProfile, IGProfile, State, Method
 from instauto.api.constants import API_BASE_URL
-from instauto.api.exceptions import WrongMethodException, IncorrectLoginDetails, InvalidUserId, BadResponse, AuthorizationError
+from instauto.api.exceptions import WrongMethodException, IncorrectLoginDetails, InvalidUserId, BadResponse
 
 logger = logging.getLogger(__name__)
 logging.captureWarnings(True)
@@ -21,10 +19,9 @@ class RequestMixin:
     device_profile: DeviceProfile
     state: State
     _user_agent: str
-    _encode_password: Callable
+    _encrypt_password: Callable
     _session: requests.Session
     _request_finished_callbacks: list
-    _handle_challenge: Callable
 
     def _build_user_agent(self) -> str:
         """Builds a user agent, making use from all required values in `self.ig_profile`, `self.device_profile` and
@@ -124,7 +121,7 @@ class RequestMixin:
         if public_api_key_id is not None: self.state.public_api_key_id = public_api_key_id
 
         public_api_key = headers.get('ig-set-password-encryption-pub-key')
-        if public_api_key is not None: self.state.public_api_key = public_api_key; self._encode_password()
+        if public_api_key is not None: self.state.public_api_key = public_api_key; self._encrypt_password()
 
     def _request(self, endpoint: str, method: Method, query: dict = None, data: Union[dict, bytes] = None, headers: Dict[str, str]
     = None, default_headers: bool = None, signed: bool = None) -> requests.Response:
@@ -238,17 +235,18 @@ class RequestMixin:
         return resp
 
     def _check_response_for_errors(self, resp: requests.Response) -> None:
-        if resp.ok:
-            return
-
         try:
             parsed = resp.json()
         except json.JSONDecodeError:
-            if resp.status_code == 404 and '/friendships/' in resp.url:
-                raise InvalidUserId(f"account id: {resp.url.split('/')[-2]} is not recognized by Instagram or you do not have a relation with this account.")
+            if not resp.ok:
+                if resp.status_code == 404 and '/friendships/' in resp.url:
+                    raise InvalidUserId(f"account id: {resp.url.split('/')[-2]} is not recognized by Instagram or you do not have a relation with this account.")
 
-            logger.exception(f"response received: \n{resp.text}\nurl: {resp.url}\nstatus code: {resp.status_code}")
-            raise BadResponse("Received a non-200 response from Instagram")
+                logger.exception(f"response received: \n{resp.text}\nurl: {resp.url}\nstatus code: {resp.status_code}")
+                raise BadResponse("Received a non-200 response from Instagram")
+            return
+        if resp.ok:
+            return
 
         if parsed.get('error_type') == 'bad_password':
             raise IncorrectLoginDetails("Instagram does not recognize the provided login details")
@@ -259,16 +257,8 @@ class RequestMixin:
             if eh:
                 return
         if parsed.get('message') == 'feedback_required':
-            if os.environ.get("ENABLE_INSTAUTO_USAGE_METRICS", True):
-                # This logs which actions cause limitations on Instagram accounts.
-                # I use this data to focus my development on area's where it's most needed.
-                requests.post('https://instauto.rooy.dev/feedback_required', data={
-                    'feedback_url': parsed.get('feedback_url'),
-                    'category': parsed.get('category')
-                })
+            # TODO: implement a handler for this error
             raise BadResponse("Something unexpected happened. Please check the IG app.")
         if parsed.get('message') == 'rate_limit_error':
             raise TimeoutError("Calm down. Please try again in a few minutes.")
-        if parsed.get('message') == 'Not authorized to view user':
-            raise AuthorizationError("This is a private user, which you do not follow.")
         raise BadResponse("Received a non-200 response from Instagram")
