@@ -21,52 +21,6 @@ logger = logging.getLogger(__name__)
 # DATACLASSES
 #####################################
 
-@dataclass
-class UserTag:
-    """
-    Contains all information about a UserTag. This can be used to set the user tag for an UserTags object.
-
-    :param user_id: Id of the tagged user
-    :param x: relative x-coordinate with 0 <= x <= 1, with 0 for left and 1 for right
-    :param y: relative y-coordinate with 0 <= y <= 1, with 0 for top and 1 for bottom
-    """
-    user_id: str = ""
-    x: float = None
-    y: float = None
-
-    def to_dict(self) -> dict:
-        data = {
-            "user_id": self.user_id,
-            "position": [
-                round(self.x, ndigits=8),
-                round(self.y, ndigits=8)
-            ]
-        }
-        return data
-
-    def __repr__(self):
-        return pprint.pformat(self.to_dict())
-
-
-@dataclass
-class UserTags:
-    """
-    Contains all information about UserTags. This can be used to set usertags for an Instagram post.
-    :param usertags: this takes a list of UserTag objects
-    """
-    usertags: List[UserTag] = None
-
-    def to_dict(self) -> dict:
-        data = {
-            "in": []
-        }
-        for usertag in self.usertags:
-            data["in"].append(usertag)
-        return data
-
-    def __repr__(self):
-        return pprint.pformat(self.to_dict())
-
 
 @dataclass
 class Location:
@@ -163,7 +117,7 @@ class Save(_Base):
 
 
 class Comment(_Base):
-    action = 'comment'
+    action = 'save'
 
     def __init__(self, media_id: str, comment_text: str, container_module: str = "something", *args, **kwargs):
         self.comment_text = comment_text
@@ -231,15 +185,13 @@ class PostFeed(_PostBase):
     device_id: str = None
 
     def __init__(self, path: Union[str, Path], caption: str,
-                 location: Optional[Location] = None, usertags: Optional[UserTags] = None,
-                 edits: Optional[Edits] = None, extra: Optional[Extra] = None,
-                 device: Optional[Device] = None, *args, **kwargs):
+                 location: Optional[Location] = None, edits: Optional[Edits] = None,
+                 extra: Optional[Extra] = None, device: Optional[Device] = None, *args, **kwargs):
         self.suggested_venue_position = -1
         self.multi_sharing = '-1'
         self.caption = caption
         self.location = location
         self.size = imagesize.get(path)
-        self.usertags = usertags
         super().__init__(path, PostLocation.Feed, edits, extra, device, *args, **kwargs)
 
 
@@ -282,21 +234,16 @@ class RetrieveByTag(cmmn.Base):
         self.only_fetch_first_carousel_media = only_fetch_first_carousel_media
         self.page = 0
         self.tag_name = tag_name
+
+
+class RetrieveLikers(_Base):
+    REQUEST = "post/get_likers.json"
+    def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
 
-class RetrieveLikers(cmmn.Base):
-    REQUEST = "post/retrieve_likers.json"
+class RetrieveCommenters(_Base):
+    REQUEST = "post/get_commenters.json"
 
-    def __init__(self, media_id: str, *args, **kwargs):
-        self.media_id = media_id
+    def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-
-
-class RetrieveCommenters(cmmn.Base):
-    REQUEST = "post/retrieve_commenters.json"
-
-    def __init__(self, media_id: str, *args, **kwargs):
-        self.media_id = media_id
-        super().__init__(*args, **kwargs)
-
