@@ -3,7 +3,7 @@ import json
 from requests import Response
 
 
-def is_resp_ok(resp: Response) -> bool:
+def _is_resp_ok(resp: Response) -> bool:
     if not resp.ok:
         return False
     if not resp.content:
